@@ -1,7 +1,7 @@
 package App::DateUtils;
 
-our $DATE = '2016-01-18'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2016-05-20'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
@@ -184,6 +184,113 @@ sub parse_duration_using_df_duration {
     parse_duration(module=>'DateTime::Format::Duration', %args);
 }
 
+$SPEC{dateconv} = {
+    v => 1.1,
+    summary => 'Convert date to another format',
+    args => {
+        date => {
+            schema => ['date*', {
+                'x.perl.coerce_to' => 'DateTime',
+                'x.perl.coerce_from' => ['str_alami'],
+            }],
+            req => 1,
+            pos => 0,
+        },
+        to => {
+            schema => ['str*', in=>[qw/epoch ymd/]], # XXX: iso8601, ...
+            default => 'epoch',
+        },
+    },
+    result_naked => 1,
+    examples => [
+        {
+            summary => 'Convert "today" to epoch',
+            args => {date => 'today'},
+            test => 0,
+        },
+        {
+            summary => 'Convert epoch to ymd',
+            args => {date => '1463702400', to=>'ymd'},
+            result => '2016-05-20',
+        },
+    ],
+};
+sub dateconv {
+    my %args = @_;
+    my $date = $args{date};
+    my $to   = $args{to};
+
+    if ($to eq 'epoch') {
+        return $date->epoch;
+    } elsif ($to eq 'ymd') {
+        return $date->ymd;
+    } else {
+        die "Unknown format '$to'";
+    }
+}
+
+$SPEC{durconv} = {
+    v => 1.1,
+    summary => 'Convert duration to another format',
+    args => {
+        duration => {
+            schema => ['duration*', {
+                'x.perl.coerce_to' => 'DateTime::Duration',
+            }],
+            req => 1,
+            pos => 0,
+        },
+        to => {
+            schema => ['str*', in=>[qw/secs hash/]], # XXX: iso8601, ...
+            default => 'secs',
+        },
+    },
+    result_naked => 1,
+    examples => [
+        {
+            summary => 'Convert "3h2m" to number of seconds',
+            args => {duration => '3h2m'},
+            result => 10920,
+        },
+    ],
+};
+sub durconv {
+    my %args = @_;
+    my $dur = $args{duration};
+    my $to  = $args{to};
+
+    if ($to eq 'secs') {
+        # approximation
+        return (
+            $dur->years       * 365*86400 +
+            $dur->months      *  30*86400 +
+            $dur->weeks       *   7*86400 +
+            $dur->days        *     86400 +
+            $dur->hours       *      3600 +
+            $dur->minutes     *        60 +
+            $dur->seconds     *         1 +
+            $dur->nanoseconds *      1e-9
+        );
+    } elsif ($to eq 'hash') {
+        my $h = {
+            years => $dur->years,
+            months => $dur->months,
+            weeks => $dur->weeks,
+            days => $dur->days,
+            hours => $dur->hours,
+            minutes => $dur->minutes,
+            seconds => $dur->seconds,
+            nanoseconds => $dur->nanoseconds,
+        };
+        for (keys %$h) {
+            delete $h->{$_} if $h->{$_} == 0;
+        }
+        return $h;
+    } else {
+        die "Unknown format '$to'";
+    }
+}
+
 1;
 # ABSTRACT: An assortment of date-/time-related CLI utilities
 
@@ -199,7 +306,7 @@ App::DateUtils - An assortment of date-/time-related CLI utilities
 
 =head1 VERSION
 
-This document describes version 0.03 of App::DateUtils (from Perl distribution App-DateUtils), released on 2016-01-18.
+This document describes version 0.04 of App::DateUtils (from Perl distribution App-DateUtils), released on 2016-05-20.
 
 =head1 SYNOPSIS
 
@@ -208,6 +315,10 @@ date/time:
 
 =over
 
+=item * L<dateconv>
+
+=item * L<durconv>
+
 =item * L<parse-date>
 
 =item * L<parse-date-using-df-natural>
@@ -221,6 +332,68 @@ date/time:
 =head1 FUNCTIONS
 
 
+=head2 dateconv(%args) -> any
+
+Convert date to another format.
+
+Examples:
+
+=over
+
+=item * Convert "today" to epoch:
+
+ dateconv(date => "today"); # -> 1463702400
+
+=item * Convert epoch to ymd:
+
+ dateconv(date => 1463702400, to => "ymd"); # -> "2016-05-20"
+
+=back
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<date>* => I<date>
+
+=item * B<to> => I<str> (default: "epoch")
+
+=back
+
+Return value:  (any)
+
+
+=head2 durconv(%args) -> any
+
+Convert duration to another format.
+
+Examples:
+
+=over
+
+=item * Convert "3h2m" to number of seconds:
+
+ durconv(duration => "3h2m"); # -> 10920
+
+=back
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<duration>* => I<duration>
+
+=item * B<to> => I<str> (default: "secs")
+
+=back
+
+Return value:  (any)
+
+
 =head2 parse_date(%args) -> [status, msg, result, meta]
 
 Parse date string(s) using one of several modules.
@@ -246,8 +419,8 @@ Result:
        original        => "23 sep 2015",
      },
      {
-       as_datetime_obj => "2016-01-19T00:00:00",
-       as_epoch        => 1453161600,
+       as_datetime_obj => "2016-05-21T00:00:00",
+       as_epoch        => 1463788800,
        is_parseable    => 1,
        original        => "tomorrow",
      },
@@ -258,7 +431,7 @@ Result:
 
 =back
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -288,7 +461,7 @@ Return value:  (any)
 
 Parse date string(s) using DateTime::Format::Natural.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -316,7 +489,7 @@ Return value:  (any)
 
 Parse duration string(s) using one of several modules.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -344,7 +517,7 @@ Return value:  (any)
 
 Parse date string(s) using DateTime::Format::Duration.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
